@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.12026';
+our $VERSION = '0.14026';
 
 $VERSION =~ /([0-9]{2})$/;
 my $compat_version = $1;
@@ -777,6 +777,9 @@ sub parse_pcfile {
     
 
     $self->append_cflags(  $self->_pc_var('cflags') );
+    if($self->static) {
+        $self->append_cflags( $self->_pc_var('cflags.private') );
+    }
     $self->append_ldflags( $self->_pc_var('libs') );
     if($self->static) {
         $self->append_ldflags( $self->_pc_var('libs.private') );
@@ -1677,6 +1680,14 @@ package itself (without dependencies).
 
 The original C implementation
 
+=item L<pkgconf|https://github.com/pkgconf/pkgconf>
+
+An alternative C implementation
+
+=item L<PkgConfig::LibPkgConf>
+
+Perl bindings for C<libpkgconf>, the same library that C<pkgconf> is built on.
+
 =item L<ExtUtils::PkgConfig>
 
 A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
@@ -1686,10 +1697,6 @@ or C<Build.PL>.
 
 Another perl implementation of pkg-config
 
-=item L<pkgconf|https://github.com/pkgconf/pkgconf>
-
-An alternative C implementation
-
 =item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
 
 Pure Ruby implementation.
